-- Johan Hambraeus
-- May 7, 2006
--
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1','Tillgngar','H','','','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('10','Immateriella anlggningstillgngar','H','','','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1010','Balanserade utgifter','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1019','Ack avskriningar balanserade utg','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1060','Hyresrtt','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1069','Ack avskrivn hyresrtt','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('11','Byggnader och mark','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1110','Byggnader','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1119','Ack avskrivn byggnader','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1130','Mark','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1140','Tomter, markomr obebyggda','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1150','Markanlggningar','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1159','Ack avskrivn markanlggn','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1190','vriga byggnader och mark','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('12','Maskiner och inventarier','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1230','Installationer','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1238','Ack nedskrivn installationer','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1239','Ack avskrivn installationer','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1250','Datorer','A','','A','IC');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1259','Ack avskrivn datorer','A','','C','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('13','Finansiella anlggningstillgngar','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1370','Uppskjuten skattefordran','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1380','Lngfristiga fordringar','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1400','Fordran hos EFS Gafsele','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1405','Fordran hos EFS Hlla','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('15','Kundfordringar','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1500','Kundfordringar','A','','A','AR');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('16','vriga kortfristiga fordringar','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1600','vr kortfristiga fordr','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1710','Frutbetalda hyror','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1730','Frutbet frskringspremier','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1740','Frutbet rnteutgifter','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1750','Upplupna hyresinkomster','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1760','Upplupna inkomstrntor','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1790','vr interimsfordringar','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('19','Kassa och Bank','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1910','Kassa','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1920','Postgiro','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1930','Checkrkningskonto','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1940','vriga bankkonto','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1941','Nordea vrdepappersfond','A','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1942','Nordea girokapitalkonto','A','','A','AR_paid:AP_paid');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2','Eget kapital och skulder','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('20','Eget kapital','H','','A','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2000','Eget kapital EFS sele','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2005','Eget kapital EFS Gafsele','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2010','Eget kapital EFS Hlla','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2070','ndamlsbestmda medel','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2091','Balanserad vinst/frlust','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2098','Vinst/frlust freg r','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2099','Redovisat resultat','A','','Q','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('22','Avsttningar','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2250','Avsttning fr skatter','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2290','vriga avsttningar','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('23','Skulder','H','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2300','Skuld till EFS Gafsele','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2310','Skuld till EFS Hlla','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2320','Skuld till fam Norlin','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2330','Checkrkningskredit','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2399','vr lngfristiga skulder','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2440','Leverantrsskulder','A','','L','AP');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2499','vr kortfristiga skulder','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2960','Upplupna utgiftsrntor','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2971','Frutbetalda hyresintkter','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2972','Frutbetalda medlemsavgifter','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2979','vriga frutbetalda intkter','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2990','vr interimsskulder','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2999','vr uppl kostn/frutbet intkter','A','','L','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3','Intkter','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('30','Allmnna gvor','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3000','Gvor via konto','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3005','Minnesgvor','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3010','Gudstjnstkollekter','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3015','Fika/kaffe/fester - gvor','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('31','ronmrkta gvor','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3100','ronmrkta gvor','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3101','Gvor barnarbete','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3102','Gvor krsng','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3103','Gvor bnegrupper','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3104','Gvor Alfa-grupper','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3105','vrigt lokalt arbete','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3106','Gvor till fastighet mm','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3109','Gvor sele allkristna gemenskap','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3110','Gvor EFS Vsterbotten','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3111','Gvor distriktskonferens','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3112','Gvor Scoutverksamhet','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3120','Gvor EFS riks','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3121','Gvor EFS riks konferens','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3122','Gvor EFS Inre mission','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3123','Gvor EFS Yttre mission','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3130','Gvor Barn i alla lnder','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3131','Gvor Johannelundsinsamling','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3132','Gvor Pskinsamling','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3133','Gvor Flodvgens offer','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('33','Frsljningsintkter','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3300','Frsljning bokbordet','A','','I','IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3350','Frsljning fika mm','A','','I','IC_sale');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34','Medlemsavgifter','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3400','Medlemsavgifter','A','','I','IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3405','Medlemsavgifter Solglimten','A','','I','IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('345','Hyresintkter','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3450','Hyresintkter, hyreskontrakt','A','','I','IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3460','Hyresintkter, enstaka tillflle','A','','I','IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3470','Hyresint Ersttning telefonkostnad','A','','I','IC_income');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('35','Bidrag','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3510','Erhllna statliga bidrag','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3520','Erhllna kommunala bidrag','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3530','Bidrag Svenska kyrkan','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3590','vriga erhllna bidrag','A','','I','AR_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('36','vriga intkter','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3690','vriga sidointker','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3731','Kassarabatter','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3740','resutjmning','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3960','Valuta kursvinst','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3972','Vinst avyttr fastigheter','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3973','Vinst avyttr maskiner/inv','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3990','vr ersttn och intker','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3994','Frskringsersttningar','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4','Utgifter','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4000','Kostnad fr predikant','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4050','Reskostnader fr predikant','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('41','Utgifter ronmrkta gvor','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4100','Kostnad ronmrkta gvor','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4101','Kostnad barnarbete','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4102','Kostnad krer','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4103','Kostnad bnegrupper','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4104','Kostnad Alfa','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4105','Kostnad vrigt lokalt arbete','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4106','Kostnad Fastighet (srskilt)','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4107','Kostnad scouting barnarbete','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4109','sele allkristna gemenskap','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4110','EFS Vsterbotten','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4111','distriktskonferens','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4120','EFS riks','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4121','EFS riks konferensinsamling','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4122','EFS inre mission','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4123','EFS yttre mission','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4130','Barn i alla lnder','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4131','Johannelundinsamling','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4132','Pskinsamling','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4133','Till Flodvgens offer','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('43','Inkpskostnader mm','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4300','Inkp bokbord','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4350','Inkp matr fika mm','A','','E','IC_cogs');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4400','Pren Vrt budskap (distr tidning)','A','','E','IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4600','Inhyrda predikanter/frelsare','A','','E','AP_amount');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4700','Tidningar, facklitteratur','A','','E','IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4900','Freningsavgifter','A','','E','IC_expense');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('50','Lokalkostnader hyrd lokal','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5010','Lokalhyra','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5020','El','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5030','Vrme hyrd lokal','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5050','Lokaltillbehr hyrd lokal','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5060','Stdning, renhllning hyrd lokal','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5070','Reparationer hyrd lokal','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5090','vr kostnader hyrd lokal','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('51','Lokalkostnader egen lokal','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5120','Belysning','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5130','Vrme','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5132','Sotning','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5140','Vatten och avlopp','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5160','Renhlln och stdning','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5170','Rep och underhll fastighet','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5191','Fastighetsskatt','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5192','Frskringsprem fastighet','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5193','Fastighetssktsel och frvaltning','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5199','vr fastighetskostnader','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('52','vriga kostnader','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5210','Hyra arbetsmaskiner','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5220','Hyra inventarier','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5290','vr hyreskostn anl tillg','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5390','vriga brnslen','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5410','Frbrukningsinventarier','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5460','Frbrukningsmaterial','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5480','Arbetsklder o skyddsmtrl','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5500','Reparation och underhll','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5710','Frakt och transport','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5800','Resekostnader','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5910','Annonsering','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5930','Reklamtrycksaker','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5990','vrig reklam','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6110','Kontorsmaterial','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6150','Trycksaker','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6210','Telefon','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6250','Porto','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6310','Frskringar','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6320','Sjlvrisker','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6340','Lmnade skadestnd','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('64','Frvaltningskostnader','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6490','vr frvaltningskostnader','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6530','Redovisningstjnster','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6540','IT-tjnster','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6550','Konsultarvoden','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('65','Bankkostnader','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6570','Bankkostnader, Nordea','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6571','Bankkostnader, Postgirot','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6572','Bankkostnader, Bankgiro','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6573','Bankkostnader, Freningssparbank','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('658','Frmmande tjnster','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6580','Advokatkostnader','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6590','vr frmmande tjnster','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7','Avskrivningar och engngskostn','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7780','Avskrivningar enligt plan','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7811','Avskrivningar balanserade utgifter','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7820','Avskrivningar byggnader/mark','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7821','Avskrivn byggnader','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7822','Avskrivn byggnadsinv','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7824','Avskrivn markanlggn','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7829','Avskrivningar vr byggnader','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7832','Avskrivn inventarier','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7833','Avskrivningar installationer','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7835','Avskrivningar datorer','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7921','Kostn av engngskaraktr ','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7960','Valutakursfrlust','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8','Financiella intkter o kostnader','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('83','Rnteintkter','H','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8300','Rnteintkter ','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8390','vr finansiella intkter','A','','I','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('84','Rntekostnader','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8400','Rntekostnader','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8490','vr finansiella kostnader','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('891','Skatter','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8910','rets skattekostnad','A','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('899','Redovisat resultat','H','','E','');
insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8999','Redovisat resultat','A','','E','');
--
INSERT INTO defaults (fldname, fldvalue) VALUES ('inventory_accno_id', (SELECT id FROM chart WHERE accno = '1130'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('income_accno_id', (SELECT id FROM chart WHERE accno = '3400'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('expense_accno_id', (SELECT id FROM chart WHERE accno = '4400'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('fxgain_accno_id', (SELECT id FROM chart WHERE accno = '3960'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('fxloss_accno_id', (SELECT id FROM chart WHERE accno = '7960'));
INSERT INTO defaults (fldname, fldvalue) VALUES ('weightunit', 'kg');
INSERT INTO defaults (fldname, fldvalue) VALUES ('precision', '2');
--
INSERT INTO curr (rn, curr, prec) VALUES (1,'SEK',2);
